%RBCupdate perform a step for computing the broadcast centrality
%   [y,B]=rbcupdate(B,b,y) performs the step, where B is the current block
%   matrix, b is the new block column, y the broadcast centrality vector.
%   This function is called by recbcen.m.

% see paper
% M. Al Mugahwi, O. De La Cruz Cabrera, C. Fenu, L. Reichel, and G. Rodriguez.
% Block matrix models for dynamic networks.
% Submitted, 2020.

function [y,B] = rbcupdate(B,b,y)

imax = 50;
tol = 1e-3;

[NN n] = size(b);
N = NN/n-1;
if N-floor(N), error('Sizes to not match.'), end

A = b(N*n+1:end,:);
b = b(1:N*n,:);

D = b;
X = b;
P = eye(n);
flag = 1;
i = 1;
fact = 1;
while flag && (i < imax)
	i = i+1;
	fact = fact*i;
	P = A*P;
	D = B*D+b*P;
	X = X + D/fact;
	flag = norm(D,inf) > tol*fact*norm(X,inf);
end
y = [y+sum(X,2); sum(expm(A),2)];
B = [B b;zeros(n,N*n) A];

