%RECBCEN recursive computation of the broadcast centrality
%   bc=recbcen(B,bsize,nstep) computes the broadcast centrality for the 
%   dynamic network with block model B, blocksize bsize, performing nstep
%   steps.
%   bc=recbcen(B,bsize,nstep,dots) prints a dot every dots steps.

% see paper
% M. Al Mugahwi, O. De La Cruz Cabrera, C. Fenu, L. Reichel, and G. Rodriguez.
% Block matrix models for dynamic networks.
% Submitted, 2020.

function y = recbcen(BN,nitem,nhour,hwarn)

if nargin<4, hwarn = inf; end

eB = expm(BN(1:nitem,1:nitem));
y = sum(eB,2);

for i = 1:nhour-1
	if ~mod(i,hwarn), fprintf('.'), end
	B = BN(1:nitem*i,1:nitem*i);
	b = BN(1:nitem*(i+1),nitem*i+1:nitem*(i+1));
	[y,B] = rbcupdate(B,b,y);
end
if isfinite(hwarn), fprintf('\n'); end

